API
===


Configuration
=============

:mod:`cnxdb.config`
-------------------

.. automodule:: cnxdb.config

   .. autofunction:: discover_settings

Scripting
=========

:mod:`cnxdb.scripting`
----------------------

.. automodule:: cnxdb.scripting

   .. autofunction:: prepare

Initialization
==============

:mod:`cnxdb.init`
-----------------

.. automodule:: cnxdb.init

:mod:`cnxdb.init.manifest`
--------------------------

.. automodule:: cnxdb.init.manifest


Migrations
==========

:mod:`cnxdb.migrations`
-----------------------

.. automodule:: cnxdb.migrations
